Page 9 of The Secret Side Of History Mystery Babylon, 209P | thedailydialectics
Description: Document: The Secret Side Of History Mystery Babylon, 209P
Keywords: The Secret Side Of History Mystery Babylon, 209P

# The Secret Side Of History Mystery Babylon, 209P — Page 9

Home

    The inscription contained a long account of the
    conquests of Darius written in the Persian, Elamite, and
    Babylonian languages. It provided the key to unlocking
    the vast treasure of ancient Babylonian literature.

    Since then, scores of expeditions digging in the ruins
    of the Euphrates-Tigris Valley have unearthed hundreds
    of thousands of inscribed tablets and monuments. The

    The most important discoveries have been found in
    the area where the Bible story began. This region was
    dotted with mounds containing the ruins of ancient cities.
    These mounds often reached a height of 100 feet and
    covered the remains of 20 cities, each built on top of the
    ruins of the previous one. Digging in these ruins,
    archaeologists have uncovered written history

    archaeologists have uncovered written history
    consistently confirming the accuracy of the Old

    have

    written

    One of Babylon's early kings was Hammurabi who
    authored the famous code bearing his name 2000 B.C.
    He ruled over an advanced civilization that had written

    laws dealing with taxes, wages, public works, even
    international commerce. Discovered in 1902,
    Hammurabi's Code, written in stone, is now in the
    Louvre Museum in Paris. Hammurabi was a

    in

    Paris.

    Louvre

    was

    contemporary of Abraham, father of the Hebrew nation.

    Abraham was also the father of the present Arab
    world through his son Ishmael. Abraham's life began in
    Ur, one of the prominent cities in Ancient Babylon.

    The Secret Side of History

    dates of some of these show that the art of writing was

    known a thousand years before the time of Moses.

    Testament.

    commerce.

    Hammurabi

    Museum